## A simple Make dir tool

#### Prerequisites

This tool is nothing but creating file in dir.

#### Usage

This is testing not for production

```
saradirmaker count name extension ( saradirmaker 10 sara .csv )

```




